@@ -2,12 +2,11 @@
 import pathlib
 from typing import Dict
 
-import sphinx
+from sphinx.application import Sphinx
 
 from ansys_sphinx_theme.latex import generate_404  # noqa: F401
 
-__version__ = "0.9.0"
-
+__version__ = "0.9.6"
 
 # Declare the fundamental paths of the theme
 THIS_PATH = pathlib.Path(__file__).parent.resolve()
@@ -67,7 +66,7 @@ def setup_default_html_theme_options(app):
 
     Parameters
     ----------
-    app : sphinx.application.Sphinx
+    app : ~sphinx.application.Sphinx
         Application instance for rendering the documentation.
 
     Notes
@@ -78,18 +77,19 @@ def setup_default_html_theme_options(app):
 
     """
     # Place all switchers and icons at the end of the navigation bar
-    app.config.html_theme_options.setdefault(
-        "navbar_end", ["version-switcher", "theme-switcher", "navbar-icon-links"]
-    )
-    app.config.html_theme_options.setdefault("collapse_navigation", "True")
+    if app.config.html_theme_options.get("switcher"):
+        app.config.html_theme_options.setdefault(
+            "navbar_end", ["version-switcher", "theme-switcher", "navbar-icon-links"]
+        )
+    app.config.html_theme_options.setdefault("collapse_navigation", True)
 
 
-def setup(app: sphinx.application.Sphinx) -> Dict:
+def setup(app: Sphinx) -> Dict:
     """Connect to the sphinx theme app.
 
     Parameters
     ----------
-    app : sphinx.application.Sphinx
+    app : ~sphinx.application.Sphinx
         Application instance for rendering the documentation.
 
     Returns
